@@ -262,7 +262,7 @@ after_legini_full(long ntr, long nlat, double *restrict poli, double *restrict p
 #endif
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(needHnm, nlat, waves, dimsp, pnm_2, hnm_2, ztemp1_2, ztemp2_2, poli, pold, pdev, pol2, pol3, coslat, gmu, gwt, PlanetRadius)
+#pragma omp parallel for default(shared)
 #endif
   for (long jgl = 0; jgl < nlat; ++jgl)
     {
@@ -318,7 +318,7 @@ after_legini(long ntr, long nlat, double *restrict poli, double *restrict pold,
   for (long jgl = 0; jgl < nlat; ++jgl) coslat[jgl] = std::sqrt(1.0 - gmu[jgl] * gmu[jgl]);
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(nlat, waves, ntr, pnm_2, work_2, gwt, gmu, poli, pold)
+#pragma omp parallel for default(shared)
 #endif
   for (long jgl = 0; jgl < nlat / 2; jgl++)
     {
