@@ -19,8 +19,8 @@
 #include "constants.h"
 #include "vertical_interp.h"
 
-constexpr double SCALEHEIGHT = -7000.;
-constexpr double SCALESLP = 101325.0;
+constexpr auto SCALEHEIGHT = -7000.0;
+constexpr auto SCALESLP = 101325.0;
 
 void
 height_to_pressure(double *phlev, const double *hlev, const long nphlev)
@@ -47,49 +47,51 @@ pressure_to_height(double *hlev, const double *plev, const long nphlev)
 
 template <typename T>
 void
-vct_to_hybrid_pressure(T *restrict fullp, T *halfp, const double *restrict vct, const T *restrict ps, long nhlev, long ngp)
+vct_to_hybrid_pressure(T *restrict fullPress, T *halfPress, const double *restrict vct, const T *restrict ps, long nhlev, long ngp)
 {
   assert(ps != nullptr);
 
-  auto halfpres = halfp;
+  auto halfpresure = halfPress;
   for (long lh = 0; lh < nhlev; lh++)
     {
       const auto zp = vct[lh];
       const auto ze = vct[lh + nhlev + 1];
-      for (long i = 0; i < ngp; i++) halfpres[i] = zp + ze * ps[i];
-      halfpres += ngp;
+      for (long i = 0; i < ngp; i++) halfpresure[i] = zp + ze * ps[i];
+      halfpresure += ngp;
     }
-  array_copy(ngp, ps, halfpres);
+  array_copy(ngp, ps, halfpresure);
 
-  if (fullp)
+  if (fullPress)
     {
-      halfpres = halfp;
-      for (long i = 0; i < ngp * nhlev; i++) fullp[i] = 0.5 * (halfpres[i] + halfpres[i + ngp]);
+      halfpresure = halfPress;
+      for (long i = 0; i < ngp * nhlev; i++) fullPress[i] = 0.5 * (halfpresure[i] + halfpresure[i + ngp]);
     }
 }
 
-template void vct_to_hybrid_pressure(float *fullp, float *halfp, const double *vct, const float *ps, long nhlev, long ngp);
-template void vct_to_hybrid_pressure(double *fullp, double *halfp, const double *vct, const double *ps, long nhlev, long ngp);
+template void vct_to_hybrid_pressure(float *fullPress, float *halfPress, const double *vct, const float *ps, long nhlev, long ngp);
+template void vct_to_hybrid_pressure(double *fullPress, double *halfPress, const double *vct, const double *ps, long nhlev, long ngp);
 
 void
-extrapolate_P(double *restrict slp, const double *restrict halfp, const double *restrict fullp, const double *restrict geop,
+extrapolate_P(double *restrict slp, const double *restrict halfPress, const double *restrict fullPress, const double *restrict geop,
               const double *restrict temp, long ngp)
 {
-  constexpr double zlapse = 0.0065;
-  const double zrg = 1.0 / PlanetGrav;
+  constexpr auto zlapse = 0.0065;
+  const auto zrg = 1.0 / PlanetGrav;
 
   for (long j = 0; j < ngp; ++j)
     {
       if (geop[j] < 0.0001 && geop[j] > -0.0001)
-        slp[j] = halfp[j];
+        {
+          slp[j] = halfPress[j];
+        }
       else
         {
-          double alpha = PlanetRD * zlapse * zrg;
-          double tstar = (1.0 + alpha * (halfp[j] / fullp[j] - 1.0)) * temp[j];
+          auto alpha = PlanetRD * zlapse * zrg;
+          auto tstar = (1.0 + alpha * (halfPress[j] / fullPress[j] - 1.0)) * temp[j];
 
           if (tstar < 255.0) tstar = 0.5 * (255.0 + tstar);
 
-          double tmsl = tstar + zlapse * zrg * geop[j];
+          auto tmsl = tstar + zlapse * zrg * geop[j];
           if (tmsl > 290.5 && tstar > 290.5)
             {
               tstar = 0.5 * (290.5 + tstar);
@@ -101,26 +103,26 @@ extrapolate_P(double *restrict slp, const double *restrict halfp, const double *
           else if (geop[j] > 0.0001 || geop[j] < -0.0001)
             alpha = PlanetRD * (tmsl - tstar) / geop[j];
 
-          const double zprt = geop[j] / (PlanetRD * tstar);
-          const double zprtal = zprt * alpha;
-          slp[j] = halfp[j] * std::exp(zprt * (1.0 - zprtal * (0.5 - zprtal / 3.0)));
+          const auto zprt = geop[j] / (PlanetRD * tstar);
+          const auto zprtal = zprt * alpha;
+          slp[j] = halfPress[j] * std::exp(zprt * (1.0 - zprtal * (0.5 - zprtal / 3.0)));
         }
     }
 }
 
 static inline double
-extrapolate_T(double pres, double halfp, double fullp, double geop, double temp)
+extrapolate_T(double pres, double halfPress, double fullPress, double geop, double temp)
 {
-  double peval = 0.0;
-  constexpr double zlapse = 0.0065;
-  const double zrg = 1.0 / PlanetGrav;
-  double tstar = (1.0 + zlapse * PlanetRD * zrg * (halfp / fullp - 1.0)) * temp;
-  const double ztsz = tstar;
-  const double z1 = tstar + zlapse * zrg * geop;
+  auto peval = 0.0;
+  constexpr auto zlapse = 0.0065;
+  const auto zrg = 1.0 / PlanetGrav;
+  auto tstar = (1.0 + zlapse * PlanetRD * zrg * (halfPress / fullPress - 1.0)) * temp;
+  const auto ztsz = tstar;
+  const auto z1 = tstar + zlapse * zrg * geop;
 
   if (tstar < 255.0) tstar = 0.5 * (255.0 + tstar);
 
-  double ztmsl = tstar + zlapse * zrg * geop;
+  auto ztmsl = tstar + zlapse * zrg * geop;
 
   if (ztmsl > 290.5 && tstar > 290.5)
     {
@@ -130,20 +132,20 @@ extrapolate_T(double pres, double halfp, double fullp, double geop, double temp)
 
   // if (ztmsl > 290.5 && tstar <= 290.5) ztmsl = 290.5;
 
-  if (pres <= halfp)
+  if (pres <= halfPress)
     {
-      peval = ((halfp - pres) * temp + (pres - fullp) * tstar) / (halfp - fullp);
+      peval = ((halfPress - pres) * temp + (pres - fullPress) * tstar) / (halfPress - fullPress);
     }
   else
     {
       ztmsl = z1;
       tstar = ztsz;
-      const double zhts = geop * zrg;
+      const auto zhts = geop * zrg;
 
-      if (zhts > 2000. && z1 > 298.)
+      if (zhts > 2000. && z1 > 298.0)
         {
-          ztmsl = 298.;
-          if (zhts < 2500.) ztmsl = 0.002 * ((2500. - zhts) * z1 + (zhts - 2000.) * ztmsl);
+          ztmsl = 298.0;
+          if (zhts < 2500.0) ztmsl = 0.002 * ((2500.0 - zhts) * z1 + (zhts - 2000.0) * ztmsl);
         }
 
       double zalph;
@@ -154,7 +156,7 @@ extrapolate_T(double pres, double halfp, double fullp, double geop, double temp)
       else
         zalph = PlanetRD * zlapse * zrg;
 
-      const double zalp = zalph * std::log(pres / halfp);
+      const auto zalp = zalph * std::log(pres / halfPress);
       peval = tstar * (1.0 + zalp * (1.0 + zalp * (0.5 + 0.16666666667 * zalp)));
     }
 
@@ -162,17 +164,17 @@ extrapolate_T(double pres, double halfp, double fullp, double geop, double temp)
 }
 
 static inline double
-extrapolate_Z(double pres, double halfp, double fullp, double geop, double temp)
+extrapolate_Z(double pres, double halfPress, double fullPress, double geop, double temp)
 {
-  constexpr double zlapse = 0.0065;
-  constexpr double ztlim = 290.5;
-  const double zrg = 1.0 / PlanetGrav;
-  double alpha = PlanetRD * zlapse * zrg;
-  double tstar = (1.0 + alpha * (halfp / fullp - 1.0)) * temp;
+  constexpr auto zlapse = 0.0065;
+  constexpr auto ztlim = 290.5;
+  const auto zrg = 1.0 / PlanetGrav;
+  auto alpha = PlanetRD * zlapse * zrg;
+  auto tstar = (1.0 + alpha * (halfPress / fullPress - 1.0)) * temp;
 
   if (tstar < 255.0) tstar = 0.5 * (255.0 + tstar);
 
-  double tmsl = tstar + zlapse * zrg * geop;
+  auto tmsl = tstar + zlapse * zrg * geop;
 
   if (tmsl > ztlim && tstar > ztlim)
     {
@@ -187,15 +189,15 @@ extrapolate_Z(double pres, double halfp, double fullp, double geop, double temp)
   else if (geop > 0.0001 || geop < -0.0001)
     alpha = PlanetRD * (tmsl - tstar) / geop;
 
-  const double zalp = std::log(pres / halfp);
-  const double zalpal = zalp * alpha;
+  const auto zalp = std::log(pres / halfPress);
+  const auto zalpal = zalp * alpha;
 
   return (geop - PlanetRD * tstar * zalp * (1.0 + zalpal * (0.5 + zalpal / 6.0))) * zrg;
 }
 
 template <typename T>
 void
-vertical_interp_T(const T *restrict geop, const T *restrict gt, T *pt, const T *restrict fullp, const T *restrict halfp,
+vertical_interp_T(const T *restrict geop, const T *restrict gt, T *pt, const T *restrict fullPress, const T *restrict halfPress,
                   const int *vertIndex, const double *restrict plev, long nplev, long ngp, long nhlev, double missval)
 {
 #ifdef _OPENMP
@@ -203,29 +205,30 @@ vertical_interp_T(const T *restrict geop, const T *restrict gt, T *pt, const T *
 #endif
   for (long lp = 0; lp < nplev; lp++)
     {
-      long nl, nh;
       const auto pres = plev[lp];
       const int *restrict vertIndexLev = vertIndex + lp * ngp;
       auto ptl = pt + lp * ngp;
 
       for (long i = 0; i < ngp; i++)
         {
-          nl = vertIndexLev[i];
+          const long nl = vertIndexLev[i];
           if (nl < 0)
-            ptl[i] = missval;
+            {
+              ptl[i] = missval;
+            }
           else
             {
               if (nl > nhlev - 2)
                 {
-                  ptl[i] = extrapolate_T(pres, halfp[nhlev * ngp + i], fullp[(nhlev - 1) * ngp + i], geop[i],
+                  ptl[i] = extrapolate_T(pres, halfPress[nhlev * ngp + i], fullPress[(nhlev - 1) * ngp + i], geop[i],
                                          gt[(nhlev - 1) * ngp + i]);
                 }
               else
                 {
-                  nh = nl + 1;
+                  const auto nh = nl + 1;
                   ptl[i] = gt[nl * ngp + i]
-                           + (pres - fullp[nl * ngp + i]) * (gt[nh * ngp + i] - gt[nl * ngp + i])
-                                 / (fullp[nh * ngp + i] - fullp[nl * ngp + i]);
+                           + (pres - fullPress[nl * ngp + i]) * (gt[nh * ngp + i] - gt[nl * ngp + i])
+                                 / (fullPress[nh * ngp + i] - fullPress[nl * ngp + i]);
                 }
             }
         }
@@ -233,55 +236,56 @@ vertical_interp_T(const T *restrict geop, const T *restrict gt, T *pt, const T *
 }
 
 // Explicit instantiation
-template void vertical_interp_T(const float *restrict geop, const float *restrict gt, float *pt, const float *restrict fullp,
-                                const float *restrict halfp, const int *vertIndex, const double *restrict plev, long nplev,
+template void vertical_interp_T(const float *restrict geop, const float *restrict gt, float *pt, const float *restrict fullPress,
+                                const float *restrict halfPress, const int *vertIndex, const double *restrict plev, long nplev,
                                 long ngp, long nhlev, double missval);
-template void vertical_interp_T(const double *restrict geop, const double *restrict gt, double *pt, const double *restrict fullp,
-                                const double *restrict halfp, const int *vertIndex, const double *restrict plev, long nplev,
+template void vertical_interp_T(const double *restrict geop, const double *restrict gt, double *pt, const double *restrict fullPress,
+                                const double *restrict halfPress, const int *vertIndex, const double *restrict plev, long nplev,
                                 long ngp, long nhlev, double missval);
 
 template <typename T>
 void
-vertical_interp_Z(const T *restrict geop, const T *restrict gz, T *pz, const T *restrict fullp, const T *restrict halfp,
+vertical_interp_Z(const T *restrict geop, const T *restrict gz, T *pz, const T *restrict fullPress, const T *restrict halfPress,
                   const int *vertIndex, const T *restrict gt, const double *restrict plev, long nplev, long ngp, long nhlev,
                   double missval)
 {
   assert(geop != nullptr);
   assert(gz != nullptr);
   assert(pz != nullptr);
-  assert(fullp != nullptr);
-  assert(halfp != nullptr);
+  assert(fullPress != nullptr);
+  assert(halfPress != nullptr);
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
   for (long lp = 0; lp < nplev; lp++)
     {
-      long nl, nh;
       const auto pres = plev[lp];
       const int *restrict vertIndexLev = vertIndex + lp * ngp;
       auto pzl = pz + lp * ngp;
 
       for (long i = 0; i < ngp; i++)
         {
-          nl = vertIndexLev[i];
+          long nl = vertIndexLev[i];
           if (nl < 0)
-            pzl[i] = missval;
+            {
+              pzl[i] = missval;
+            }
           else
             {
-              if (pres > halfp[(nl + 1) * ngp + i]) nl++;
+              if (pres > halfPress[(nl + 1) * ngp + i]) nl++;
 
               if (nl > nhlev - 1)
                 {
-                  pzl[i] = extrapolate_Z(pres, halfp[nhlev * ngp + i], fullp[(nhlev - 1) * ngp + i], geop[i],
+                  pzl[i] = extrapolate_Z(pres, halfPress[nhlev * ngp + i], fullPress[(nhlev - 1) * ngp + i], geop[i],
                                          gt[(nhlev - 1) * ngp + i]);
                 }
               else
                 {
-                  nh = nl + 1;
+                  const auto nh = nl + 1;
                   pzl[i] = gz[nl * ngp + i]
-                           + (pres - halfp[nl * ngp + i]) * (gz[nh * ngp + i] - gz[nl * ngp + i])
-                                 / (halfp[nh * ngp + i] - halfp[nl * ngp + i]);
+                           + (pres - halfPress[nl * ngp + i]) * (gz[nh * ngp + i] - gz[nl * ngp + i])
+                                 / (halfPress[nh * ngp + i] - halfPress[nl * ngp + i]);
                 }
             }
         }
@@ -289,72 +293,72 @@ vertical_interp_Z(const T *restrict geop, const T *restrict gz, T *pz, const T *
 }
 
 // Explicit instantiation
-template void vertical_interp_Z(const float *restrict geop, const float *restrict gz, float *pz, const float *restrict fullp,
-                                const float *restrict halfp, const int *vertIndex, const float *restrict gt,
+template void vertical_interp_Z(const float *restrict geop, const float *restrict gz, float *pz, const float *restrict fullPress,
+                                const float *restrict halfPress, const int *vertIndex, const float *restrict gt,
                                 const double *restrict plev, long nplev, long ngp, long nhlev, double missval);
-template void vertical_interp_Z(const double *restrict geop, const double *restrict gz, double *pz, const double *restrict fullp,
-                                const double *restrict halfp, const int *vertIndex, const double *restrict gt,
+template void vertical_interp_Z(const double *restrict geop, const double *restrict gz, double *pz, const double *restrict fullPress,
+                                const double *restrict halfPress, const int *vertIndex, const double *restrict gt,
                                 const double *restrict plev, long nplev, long ngp, long nhlev, double missval);
 
 template <typename T>
 static inline double
-vertical_interp_X_kernel(const T *restrict gt, const T *restrict hyb_press, long nl, double pres, long ngp, long nhlev,
+vertical_interp_X_kernel(const T *restrict arrayIn, const T *restrict levels3D, long nl, double level, long ngp, long nhlev,
                          double missval)
 {
   const auto nh = nl + ngp;
   return (nl < 0) ? missval
-                  : ((nh >= ngp * nhlev) ? gt[nl]
-                                         : gt[nl] + (pres - hyb_press[nl]) * (gt[nh] - gt[nl]) / (hyb_press[nh] - hyb_press[nl]));
+                  : ((nh >= ngp * nhlev) ? arrayIn[nl]
+                                         : arrayIn[nl] + (level - levels3D[nl]) * (arrayIn[nh] - arrayIn[nl]) / (levels3D[nh] - levels3D[nl]));
 }
 
 template <typename T>
 void
-vertical_interp_X(const T *restrict gt, T *pt, const T *hyb_press, const int *vertIndex, const double *restrict plev, long nplev,
+vertical_interp_X(const T *restrict arrayIn3D, T *arrayOut3D, const T *levels3D, const int *vertIndex3D, const double *restrict levels, long numLevels,
                   long ngp, long nhlev, double missval)
 {
-  if (nplev > 3)
+  if (numLevels > 3)
     {
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
-      for (long lp = 0; lp < nplev; lp++)
+      for (long lp = 0; lp < numLevels; lp++)
         {
-          auto pres = plev[lp];
-          const int *restrict vertIndexLev = vertIndex + lp * ngp;
-          auto ptl = pt + lp * ngp;
+          const auto level = levels[lp];
+          const int *restrict vertIndex = vertIndex3D + lp * ngp;
+          auto arrayOut = arrayOut3D + lp * ngp;
           for (long i = 0; i < ngp; i++)
             {
-              ptl[i] = vertical_interp_X_kernel(gt, hyb_press, vertIndexLev[i] * ngp + i, pres, ngp, nhlev, missval);
+              arrayOut[i] = vertical_interp_X_kernel(arrayIn3D, levels3D, vertIndex[i] * ngp + i, level, ngp, nhlev, missval);
             }
         }
     }
   else
     {
-      for (long lp = 0; lp < nplev; lp++)
+      for (long lp = 0; lp < numLevels; lp++)
         {
-          auto pres = plev[lp];
-          const int *restrict vertIndexLev = vertIndex + lp * ngp;
-          auto *restrict ptl = pt + lp * ngp;
+          const auto level = levels[lp];
+          const int *restrict vertIndex = vertIndex3D + lp * ngp;
+          auto *restrict arrayOut = arrayOut3D + lp * ngp;
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
           for (long i = 0; i < ngp; i++)
             {
-              ptl[i] = vertical_interp_X_kernel(gt, hyb_press, vertIndexLev[i] * ngp + i, pres, ngp, nhlev, missval);
+              arrayOut[i] = vertical_interp_X_kernel(arrayIn3D, levels3D, vertIndex[i] * ngp + i, level, ngp, nhlev, missval);
             }
         }
     }
 }
 
 // Explicit instantiation
-template void vertical_interp_X(const float *restrict gt, float *pt, const float *hyb_press, const int *vertIndex,
-                                const double *restrict plev, long nplev, long ngp, long nhlev, double missval);
-template void vertical_interp_X(const double *restrict gt, double *pt, const double *hyb_press, const int *vertIndex,
-                                const double *restrict plev, long nplev, long ngp, long nhlev, double missval);
+template void vertical_interp_X(const float *restrict arrayIn3D, float *arrayOut3D, const float *levels3D, const int *vertIndex3D,
+                                const double *levels, long numLevels, long ngp, long nhlev, double missval);
+template void vertical_interp_X(const double *restrict arrayIn3D, double *arrayOut3D, const double *levels3D, const int *vertIndex3D,
+                                const double *levels, long numLevels, long ngp, long nhlev, double missval);
 
 template <typename T>
 void
-gen_vert_index(int *vertIndex, const double *restrict plev, const T *restrict fullp, long ngp, long nplev, long nhlev,
+gen_vert_index(int *vertIndex, const double *restrict plev, const T *restrict levels3D, long ngp, long nplev, long nhlev,
                bool lreverse)
 {
   varray_fill(ngp * nplev, vertIndex, 0);
@@ -368,7 +372,7 @@ gen_vert_index(int *vertIndex, const double *restrict plev, const T *restrict fu
       auto *restrict vertIndexLev = vertIndex + lp * ngp;
       for (long lh = 0; lh < nhlev; lh++)
         {
-          const auto *restrict fullpx = fullp + lh * ngp;
+          const auto *restrict fullpx = levels3D + lh * ngp;
           if (lreverse)
             {
               for (long i = 0; i < ngp; i++)
@@ -388,9 +392,9 @@ gen_vert_index(int *vertIndex, const double *restrict plev, const T *restrict fu
 }
 
 // Explicit instantiation
-template void gen_vert_index(int *vertIndex, const double *plev, const float *fullp, long ngp, long nplev, long nhlev,
+template void gen_vert_index(int *vertIndex, const double *plev, const float *levels3D, long ngp, long nplev, long nhlev,
                              bool lreverse);
-template void gen_vert_index(int *vertIndex, const double *plev, const double *fullp, long ngp, long nplev, long nhlev,
+template void gen_vert_index(int *vertIndex, const double *plev, const double *levels3D, long ngp, long nplev, long nhlev,
                              bool lreverse);
 
 template <typename T>
